RawStackAccess

Trait RawStackAccess 

pub trait RawStackAccess: Sealed {
    // Required methods
    unsafe fn to_object(&self, index: i32) -> Option<TValue>;
    unsafe fn push_value_internal(&self, value: TValue) -> VmErrorResult;
    unsafe fn push_table(&self, table: Table) -> VmErrorResult;
    unsafe fn push_class(&self, class: Class) -> VmErrorResult;
}
Unstable raw stack-address conversion capability.

Safety

Indices must be valid for this thread under the corresponding Luau stack rule. Returned views and cursors borrow no storage and are invalidated by stack relocation, stack mutation, reset, close, or VM destruction.

Required Methods

unsafe fn to_object(&self, index: i32) -> Option<TValue>

luaA_toobject

unsafe fn push_value_internal(&self, value: TValue) -> VmErrorResult

luaA_pushvalue

unsafe fn push_table(&self, table: Table) -> VmErrorResult

unsafe fn push_class(&self, class: Class) -> VmErrorResult

luaA_pushclass

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors