GlobalState

Struct GlobalState 

pub struct GlobalState { /* private fields */ }
Non-owning identity of a VM’s global state record.

Safety model for unsafe methods

The owning VM must remain live. Returned threads, objects, pointers, and record views are non-owning and must not outlive their storage. Mutation must be serialized with VM execution and preserve the owning subsystem’s invariants.

Implementations

Source

impl GlobalState

Source

impl GlobalState

pub unsafe fn uv_head(&self) -> UpVal

Source

impl GlobalState

pub fn gc_state(&self) -> u8

pub fn set_gc_state(&self, gc_state: u8)

pub fn gray(&self) -> Option<GcObject>

pub fn set_gray(&self, gray: Option<GcObject>)

pub fn gray_again(&self) -> Option<GcObject>

pub fn set_gray_again(&self, gray_again: Option<GcObject>)

pub fn weak(&self) -> Option<GcObject>

pub fn set_weak(&self, weak: Option<GcObject>)

Source

impl GlobalState

pub fn white(&self) -> u8

luaC_white

pub unsafe fn keep_invariant(&self) -> bool

keepinvariant

pub unsafe fn is_dead(&self, object: GcObject) -> bool

isdead

pub unsafe fn make_white(&self, object: GcObject)

makewhite

Source

impl GlobalState

Source

impl GlobalState

pub unsafe fn type_name(&self, tag: usize) -> TString

pub unsafe fn tm_name(&self, event: usize) -> TString

pub fn metatable(&self, tag: usize) -> Option<Table>

Source

impl GlobalState

pub fn callbacks(&self) -> *mut LuaCallbacks

Returns the VM-owned public callback record address.

The pointer is for quiescent installation and focused VM reads. It does not establish a Rust borrow and must not be used to mutate the record while the VM is executing.

pub fn execution_callbacks(&self) -> *mut LuaExecutionCallbacks

Returns the VM-owned execution callback record address.

The pointer is for quiescent installation and focused VM reads. It does not establish a Rust borrow and must not be used to mutate the record while the VM is executing.

Source

impl GlobalState

pub const unsafe fn from_raw(raw: NonNull<RawGlobalState>) -> Self

pub unsafe fn main_thread(&self) -> Thread

pub fn encode_pointer(&self, pointer: usize) -> usize

pub fn registry(&self) -> TValue

pub fn pseudo_temp(&self) -> TValue

pub fn registry_free(&self) -> i32

pub fn set_registry_free(&self, registry_free: i32)

Source

impl GlobalState

Source

impl GlobalState

pub fn userdata_metatable(&self, tag: usize) -> Option<Table>

pub fn set_userdata_metatable(&self, tag: usize, table: Option<Table>)

pub fn userdata_dtor(&self, tag: usize) -> Option<LuaDestructor>

pub fn set_userdata_dtor(&self, tag: usize, destructor: Option<LuaDestructor>)

pub fn userdata_mark(&self, tag: usize) -> Option<LuaUserdataMark>

pub fn set_userdata_mark(&self, tag: usize, mark: Option<LuaUserdataMark>)

pub fn light_userdata_name(&self, tag: usize) -> Option<TString>

pub fn set_light_userdata_name(&self, tag: usize, name: Option<TString>)