#[repr(C)]pub struct LuaExecutionCallbacks {
pub context: *mut (),
pub close: Option<ExecutionClose>,
pub destroy: Option<ExecutionDestroy>,
pub enter: Option<ExecutionEnter>,
pub disable: Option<ExecutionDisable>,
pub get_memory_size: Option<ExecutionMemorySize>,
pub get_type_mapping: Option<ExecutionTypeMapping>,
pub get_counter_data: Option<ExecutionCounterData>,
pub inline_function: Option<ExecutionInlineFunction>,
}Expand description
Execution-engine callback record installed by an advanced embedder.
The record must be installed or updated as one coherent operation while the VM is quiescent. Its fields are plain, non-atomic storage and must not be mutated concurrently with VM execution.
Fields
context: *mut ()close: Option<ExecutionClose>destroy: Option<ExecutionDestroy>enter: Option<ExecutionEnter>disable: Option<ExecutionDisable>get_memory_size: Option<ExecutionMemorySize>get_type_mapping: Option<ExecutionTypeMapping>get_counter_data: Option<ExecutionCounterData>inline_function: Option<ExecutionInlineFunction>Trait Implementations
Sourceimpl Clone for LuaExecutionCallbacks
impl Clone for LuaExecutionCallbacks
Sourcefn clone(&self) -> LuaExecutionCallbacks
fn clone(&self) -> LuaExecutionCallbacks
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LuaExecutionCallbacks
Sourceimpl Default for LuaExecutionCallbacks
impl Default for LuaExecutionCallbacks
Sourcefn default() -> LuaExecutionCallbacks
fn default() -> LuaExecutionCallbacks
Returns the “default value” for a type. Read more