pub struct Thread { /* private fields */ }Expand description
A non-owning Luau thread handle.
Thread does not keep the VM alive and does not encode exclusive access
to the VM stack. It is deliberately !Send and !Sync through its raw
state representation.
Safety model for unsafe methods
Unless a method documents stricter requirements, every unsafe Thread
operation requires a live thread belonging to a live VM. Stack indices,
stack shapes, counts, tags, and pointer arguments must satisfy the
corresponding Luau API operation’s contract. The caller must provide
sufficient stack capacity where the operation does not grow the stack,
prevent reentrant or concurrent access to VM-owned records, and treat any
operation that can allocate or execute code as a possible GC transition.
Returned pointers and raw handles are non-owning and may be invalidated by
stack relocation, collection, closure, reset, or VM destruction.
Implementations
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_bit32(&self) -> NativeCallResult
pub unsafe fn open_bit32(&self) -> NativeCallResult
luaopen_bit32
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_buffer(&self) -> NativeCallResult
pub unsafe fn open_buffer(&self) -> NativeCallResult
luaopen_buffer
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_class(&self) -> NativeCallResult
pub unsafe fn open_class(&self) -> NativeCallResult
luaopen_class
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_coroutine(&self) -> NativeCallResult
pub unsafe fn open_coroutine(&self) -> NativeCallResult
luaopen_coroutine
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_debug(&self) -> NativeCallResult
pub unsafe fn open_debug(&self) -> NativeCallResult
luaopen_debug
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_integer(&self) -> NativeCallResult
pub unsafe fn open_integer(&self) -> NativeCallResult
luaopen_integer
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_string(&self) -> NativeCallResult
pub unsafe fn open_string(&self) -> NativeCallResult
luaopen_string
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_table(&self) -> NativeCallResult
pub unsafe fn open_table(&self) -> NativeCallResult
luaopen_table
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn open_vector(&self) -> NativeCallResult
pub unsafe fn open_vector(&self) -> NativeCallResult
luaopen_vector
Sourceimpl Thread
impl Thread
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn push_where(&self, level: i32) -> VmErrorResult
pub unsafe fn push_where(&self, level: i32) -> VmErrorResult
luaL_where
Sourcepub unsafe fn lua_error<'a, T>(
&self,
format: impl AsRef<[u8]>,
args: impl AsMut<[Arg<'a>]>,
) -> VmErrorResult<T>
pub unsafe fn lua_error<'a, T>( &self, format: impl AsRef<[u8]>, args: impl AsMut<[Arg<'a>]>, ) -> VmErrorResult<T>
luaL_error
Sourcepub unsafe fn lua_type_error<T>(
&self,
argument: i32,
expected_type: impl AsRef<[u8]>,
) -> VmErrorResult<T>
pub unsafe fn lua_type_error<T>( &self, argument: i32, expected_type: impl AsRef<[u8]>, ) -> VmErrorResult<T>
luaL_typeerror
Sourcepub unsafe fn lua_arg_expected(
&self,
condition: bool,
argument: i32,
expected_type: &str,
) -> VmErrorResult
pub unsafe fn lua_arg_expected( &self, condition: bool, argument: i32, expected_type: &str, ) -> VmErrorResult
luaL_argexpected
Sourcepub unsafe fn lua_arg_error<T>(
&self,
argument: i32,
message: impl AsRef<[u8]>,
) -> VmErrorResult<T>
pub unsafe fn lua_arg_error<T>( &self, argument: i32, message: impl AsRef<[u8]>, ) -> VmErrorResult<T>
luaL_argerror
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn lua_check_stack(
&self,
size: i32,
message: Option<&str>,
) -> VmErrorResult
pub unsafe fn lua_check_stack( &self, size: i32, message: Option<&str>, ) -> VmErrorResult
luaL_checkstack
Sourcepub unsafe fn check_type(
&self,
argument: i32,
expected_type: i32,
) -> VmErrorResult
pub unsafe fn check_type( &self, argument: i32, expected_type: i32, ) -> VmErrorResult
luaL_checktype
Sourcepub unsafe fn check_any(&self, argument: i32) -> VmErrorResult
pub unsafe fn check_any(&self, argument: i32) -> VmErrorResult
luaL_checkany
Sourcepub unsafe fn check_string(&self, argument: i32) -> VmErrorResult<&BStr>
pub unsafe fn check_string(&self, argument: i32) -> VmErrorResult<&BStr>
luaL_checklstring
Sourcepub unsafe fn opt_string(&self, argument: i32) -> VmErrorResult<Option<&BStr>>
pub unsafe fn opt_string(&self, argument: i32) -> VmErrorResult<Option<&BStr>>
luaL_optlstring
Sourcepub unsafe fn check_buffer(
&self,
argument: i32,
) -> VmErrorResult<(*mut u8, usize)>
pub unsafe fn check_buffer( &self, argument: i32, ) -> VmErrorResult<(*mut u8, usize)>
luaL_checkbuffer
Sourcepub unsafe fn check_userdata(
&self,
argument: i32,
type_name: &str,
) -> VmErrorResult<*mut ()>
pub unsafe fn check_userdata( &self, argument: i32, type_name: &str, ) -> VmErrorResult<*mut ()>
luaL_checkudata
Sourcepub unsafe fn check_userdata_tagged(
&self,
argument: i32,
tag: i32,
) -> VmErrorResult<*mut ()>
pub unsafe fn check_userdata_tagged( &self, argument: i32, tag: i32, ) -> VmErrorResult<*mut ()>
luaL_checkudatatagged
Sourcepub unsafe fn check_number(&self, argument: i32) -> VmErrorResult<f64>
pub unsafe fn check_number(&self, argument: i32) -> VmErrorResult<f64>
luaL_checknumber
Sourcepub unsafe fn opt_number(
&self,
argument: i32,
default: f64,
) -> VmErrorResult<f64>
pub unsafe fn opt_number( &self, argument: i32, default: f64, ) -> VmErrorResult<f64>
luaL_optnumber
Sourcepub unsafe fn check_boolean(&self, argument: i32) -> VmErrorResult<i32>
pub unsafe fn check_boolean(&self, argument: i32) -> VmErrorResult<i32>
luaL_checkboolean
Sourcepub unsafe fn opt_boolean(
&self,
argument: i32,
default: i32,
) -> VmErrorResult<i32>
pub unsafe fn opt_boolean( &self, argument: i32, default: i32, ) -> VmErrorResult<i32>
luaL_optboolean
Sourcepub unsafe fn check_integer(&self, argument: i32) -> VmErrorResult<i32>
pub unsafe fn check_integer(&self, argument: i32) -> VmErrorResult<i32>
luaL_checkinteger
Sourcepub unsafe fn opt_integer(
&self,
argument: i32,
default: i32,
) -> VmErrorResult<i32>
pub unsafe fn opt_integer( &self, argument: i32, default: i32, ) -> VmErrorResult<i32>
luaL_optinteger
Sourcepub unsafe fn check_integer64(&self, argument: i32) -> VmErrorResult<i64>
pub unsafe fn check_integer64(&self, argument: i32) -> VmErrorResult<i64>
luaL_checkinteger64
Sourcepub unsafe fn opt_integer64(
&self,
argument: i32,
default: i64,
) -> VmErrorResult<i64>
pub unsafe fn opt_integer64( &self, argument: i32, default: i64, ) -> VmErrorResult<i64>
luaL_optinteger64
Sourcepub unsafe fn check_unsigned(&self, argument: i32) -> VmErrorResult<u32>
pub unsafe fn check_unsigned(&self, argument: i32) -> VmErrorResult<u32>
luaL_checkunsigned
Sourcepub unsafe fn opt_unsigned(
&self,
argument: i32,
default: u32,
) -> VmErrorResult<u32>
pub unsafe fn opt_unsigned( &self, argument: i32, default: u32, ) -> VmErrorResult<u32>
luaL_optunsigned
Sourcepub unsafe fn check_vector(&self, argument: i32) -> VmErrorResult<[f32; 3]>
pub unsafe fn check_vector(&self, argument: i32) -> VmErrorResult<[f32; 3]>
luaL_checkvector
Sourcepub unsafe fn opt_vector(
&self,
argument: i32,
) -> VmErrorResult<Option<[f32; 3]>>
pub unsafe fn opt_vector( &self, argument: i32, ) -> VmErrorResult<Option<[f32; 3]>>
luaL_optvector
Sourcepub unsafe fn check_option(
&self,
argument: i32,
default: Option<&str>,
options: &[&str],
) -> VmErrorResult<i32>
pub unsafe fn check_option( &self, argument: i32, default: Option<&str>, options: &[&str], ) -> VmErrorResult<i32>
luaL_checkoption
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn lua_type_name(&self, index: i32) -> LuaString
pub unsafe fn lua_type_name(&self, index: i32) -> LuaString
luaL_typename
Sourcepub unsafe fn lua_to_string(&self, index: i32) -> VmResult<&BStr>
pub unsafe fn lua_to_string(&self, index: i32) -> VmResult<&BStr>
luaL_tolstring
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn push_native_closure_k(
&self,
function: RawNativeFunction,
debug_name: Option<&'static str>,
upvalues: i32,
continuation: Option<RawNativeContinuation>,
) -> VmErrorResult
pub unsafe fn push_native_closure_k( &self, function: RawNativeFunction, debug_name: Option<&'static str>, upvalues: i32, continuation: Option<RawNativeContinuation>, ) -> VmErrorResult
lua_pushcclosurek
Sourcepub unsafe fn push_native_function(
&self,
function: RawNativeFunction,
debug_name: Option<&'static str>,
) -> VmErrorResult
pub unsafe fn push_native_function( &self, function: RawNativeFunction, debug_name: Option<&'static str>, ) -> VmErrorResult
lua_pushcfunction
Sourcepub unsafe fn push_native_closure(
&self,
function: RawNativeFunction,
debug_name: Option<&'static str>,
upvalues: i32,
) -> VmErrorResult
pub unsafe fn push_native_closure( &self, function: RawNativeFunction, debug_name: Option<&'static str>, upvalues: i32, ) -> VmErrorResult
lua_pushcclosure
Sourcepub unsafe fn to_native_function(&self, index: i32) -> Option<RawNativeFunction>
pub unsafe fn to_native_function(&self, index: i32) -> Option<RawNativeFunction>
lua_tocfunction
Sourcepub unsafe fn clone_function(&self, index: i32) -> VmErrorResult
pub unsafe fn clone_function(&self, index: i32) -> VmErrorResult
lua_clonefunction
Sourcepub unsafe fn uses_export(&self, index: i32) -> i32
pub unsafe fn uses_export(&self, index: i32) -> i32
lua_usesexport
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn protected_call(
&self,
n_args: i32,
n_results: i32,
errfunc: i32,
) -> VmResult
pub unsafe fn protected_call( &self, n_args: i32, n_results: i32, errfunc: i32, ) -> VmResult
lua_pcall
Sourcepub unsafe fn protected_native_call(
&self,
function: RawNativeFunction,
userdata: *mut (),
) -> VmResult
pub unsafe fn protected_native_call( &self, function: RawNativeFunction, userdata: *mut (), ) -> VmResult
lua_cpcall
Sourcepub unsafe fn error<T>(&self) -> VmErrorResult<T>
pub unsafe fn error<T>(&self) -> VmErrorResult<T>
lua_error
Sourcepub unsafe fn yield_current(&self, results: i32) -> NativeCallResult
pub unsafe fn yield_current(&self, results: i32) -> NativeCallResult
lua_yield
Sourcepub unsafe fn break_current(&self) -> NativeCallResult
pub unsafe fn break_current(&self) -> NativeCallResult
lua_break
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn call_yieldable(
&self,
nargs: i32,
nresults: i32,
) -> NativeCallResult
pub unsafe fn call_yieldable( &self, nargs: i32, nresults: i32, ) -> NativeCallResult
luaL_callyieldable
Sourcepub unsafe fn protected_call_yieldable(
&self,
nargs: i32,
nresults: i32,
errfunc: i32,
) -> NativeCallResult
pub unsafe fn protected_call_yieldable( &self, nargs: i32, nresults: i32, errfunc: i32, ) -> NativeCallResult
luaL_pcallyieldable
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn stack_depth(&self) -> i32
pub unsafe fn stack_depth(&self) -> i32
lua_stackdepth
Sourcepub unsafe fn get_info(
&self,
level: i32,
what: &str,
ar: &mut LuaDebug,
) -> VmErrorResult<i32>
pub unsafe fn get_info( &self, level: i32, what: &str, ar: &mut LuaDebug, ) -> VmErrorResult<i32>
lua_getinfo
Sourcepub unsafe fn get_argument(
&self,
level: i32,
argument: i32,
) -> VmErrorResult<i32>
pub unsafe fn get_argument( &self, level: i32, argument: i32, ) -> VmErrorResult<i32>
lua_getargument
Sourcepub unsafe fn get_local(
&self,
level: i32,
local: i32,
) -> VmErrorResult<Option<LuaString>>
pub unsafe fn get_local( &self, level: i32, local: i32, ) -> VmErrorResult<Option<LuaString>>
lua_getlocal
Sourcepub unsafe fn get_upvalue(
&self,
function_index: i32,
upvalue_index: i32,
) -> VmErrorResult<Option<LuaString>>
pub unsafe fn get_upvalue( &self, function_index: i32, upvalue_index: i32, ) -> VmErrorResult<Option<LuaString>>
lua_getupvalue
Sourcepub unsafe fn set_upvalue(
&self,
function_index: i32,
upvalue_index: i32,
) -> Option<LuaString>
pub unsafe fn set_upvalue( &self, function_index: i32, upvalue_index: i32, ) -> Option<LuaString>
lua_setupvalue
Sourcepub unsafe fn single_step(&self, enabled: i32)
pub unsafe fn single_step(&self, enabled: i32)
lua_singlestep
Sourcepub unsafe fn breakpoint(
&self,
function_index: i32,
line: i32,
enabled: i32,
) -> VmErrorResult<i32>
pub unsafe fn breakpoint( &self, function_index: i32, line: i32, enabled: i32, ) -> VmErrorResult<i32>
lua_breakpoint
Sourcepub unsafe fn has_custom_execution(&self, level: i32) -> i32
pub unsafe fn has_custom_execution(&self, level: i32) -> i32
lua_hascustomexecution
Sourcepub unsafe fn in_custom_execution(&self, level: i32) -> i32
pub unsafe fn in_custom_execution(&self, level: i32) -> i32
lua_incustomexecution
Sourcepub unsafe fn at_breakpoint(&self) -> i32
pub unsafe fn at_breakpoint(&self) -> i32
lua_atbreakpoint
Sourcepub unsafe fn get_coverage(
&self,
function_index: i32,
context: *mut (),
callback: LuaCoverage,
) -> VmErrorResult
pub unsafe fn get_coverage( &self, function_index: i32, context: *mut (), callback: LuaCoverage, ) -> VmErrorResult
lua_getcoverage
Sourcepub unsafe fn get_counters(
&self,
function_index: i32,
context: *mut (),
function_visit: LuaCounterFunction,
counter_visit: LuaCounterValue,
)
pub unsafe fn get_counters( &self, function_index: i32, context: *mut (), function_visit: LuaCounterFunction, counter_visit: LuaCounterValue, )
lua_getcounters
Sourcepub unsafe fn debug_trace(&self) -> VmErrorResult<BString>
pub unsafe fn debug_trace(&self) -> VmErrorResult<BString>
lua_debugtrace
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn memory_dump(
&self,
output: &mut BString,
category_name: Option<&mut dyn GcCategoryNamer>,
)
pub unsafe fn memory_dump( &self, output: &mut BString, category_name: Option<&mut dyn GcCategoryNamer>, )
lua_memorydump
Sourcepub unsafe fn allocation_rate(&self) -> i64
pub unsafe fn allocation_rate(&self) -> i64
lua_allocationrate
Sourcepub unsafe fn set_mem_cat(&self, category: i32)
pub unsafe fn set_mem_cat(&self, category: i32)
lua_setmemcat
Sourcepub unsafe fn total_bytes(&self, category: i32) -> usize
pub unsafe fn total_bytes(&self, category: i32) -> usize
lua_totalbytes
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn check_stack(&self, size: i32) -> i32
pub unsafe fn check_stack(&self, size: i32) -> i32
lua_checkstack
Sourcepub unsafe fn raw_check_stack(&self, size: i32) -> VmErrorResult
pub unsafe fn raw_check_stack(&self, size: i32) -> VmErrorResult
lua_rawcheckstack
Sourcepub unsafe fn set_top(&self, index: i32) -> VmErrorResult
pub unsafe fn set_top(&self, index: i32) -> VmErrorResult
lua_settop
Sourcepub unsafe fn restore_top(&self, top: i32)
pub unsafe fn restore_top(&self, top: i32)
Restores the stack top to a previous absolute top.
Sourcepub unsafe fn push_value(&self, index: i32) -> VmErrorResult
pub unsafe fn push_value(&self, index: i32) -> VmErrorResult
lua_pushvalue
Sourcepub unsafe fn x_move(&self, to: &Thread, count: i32) -> VmErrorResult
pub unsafe fn x_move(&self, to: &Thread, count: i32) -> VmErrorResult
lua_xmove
Sourcepub unsafe fn x_push(&self, to: &Thread, index: i32) -> VmErrorResult
pub unsafe fn x_push(&self, to: &Thread, index: i32) -> VmErrorResult
lua_xpush
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn push_nil(&self) -> VmErrorResult
pub unsafe fn push_nil(&self) -> VmErrorResult
lua_pushnil
Sourcepub unsafe fn push_number(&self, value: f64) -> VmErrorResult
pub unsafe fn push_number(&self, value: f64) -> VmErrorResult
lua_pushnumber
Sourcepub unsafe fn push_integer(&self, value: i32) -> VmErrorResult
pub unsafe fn push_integer(&self, value: i32) -> VmErrorResult
lua_pushinteger
Sourcepub unsafe fn push_integer64(&self, value: i64) -> VmErrorResult
pub unsafe fn push_integer64(&self, value: i64) -> VmErrorResult
lua_pushinteger64
Sourcepub unsafe fn push_unsigned(&self, value: u32) -> VmErrorResult
pub unsafe fn push_unsigned(&self, value: u32) -> VmErrorResult
lua_pushunsigned
Sourcepub unsafe fn push_vector(&self, components: [f32; 3]) -> VmErrorResult
pub unsafe fn push_vector(&self, components: [f32; 3]) -> VmErrorResult
lua_pushvector
Sourcepub unsafe fn push_boolean(&self, value: i32) -> VmErrorResult
pub unsafe fn push_boolean(&self, value: i32) -> VmErrorResult
lua_pushboolean
Sourcepub unsafe fn push_light_userdata_tagged(
&self,
pointer: *mut (),
tag: i32,
) -> VmErrorResult
pub unsafe fn push_light_userdata_tagged( &self, pointer: *mut (), tag: i32, ) -> VmErrorResult
lua_pushlightuserdatatagged
Sourcepub unsafe fn push_light_userdata(&self, pointer: *mut ()) -> VmErrorResult
pub unsafe fn push_light_userdata(&self, pointer: *mut ()) -> VmErrorResult
lua_pushlightuserdata
Sourcepub unsafe fn push_string(&self, bytes: impl AsRef<[u8]>) -> VmErrorResult
pub unsafe fn push_string(&self, bytes: impl AsRef<[u8]>) -> VmErrorResult
lua_pushlstring
Sourcepub unsafe fn push_optional_string(
&self,
bytes: Option<impl AsRef<[u8]>>,
) -> VmErrorResult
pub unsafe fn push_optional_string( &self, bytes: Option<impl AsRef<[u8]>>, ) -> VmErrorResult
lua_pushstring
Sourcepub unsafe fn push_vfstring<'a>(
&self,
format: &str,
args: impl AsMut<[Arg<'a>]>,
) -> VmErrorResult<LuaString>
pub unsafe fn push_vfstring<'a>( &self, format: &str, args: impl AsMut<[Arg<'a>]>, ) -> VmErrorResult<LuaString>
lua_pushvfstring
Sourcepub unsafe fn push_fstring<'a>(
&self,
format: &str,
args: impl AsMut<[Arg<'a>]>,
) -> VmErrorResult<LuaString>
pub unsafe fn push_fstring<'a>( &self, format: &str, args: impl AsMut<[Arg<'a>]>, ) -> VmErrorResult<LuaString>
lua_pushfstring
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn is_light_userdata(&self, index: i32) -> i32
pub unsafe fn is_light_userdata(&self, index: i32) -> i32
lua_islightuserdata
Sourcepub unsafe fn is_function(&self, index: i32) -> i32
pub unsafe fn is_function(&self, index: i32) -> i32
lua_isfunction
Sourcepub unsafe fn is_boolean(&self, index: i32) -> i32
pub unsafe fn is_boolean(&self, index: i32) -> i32
lua_isboolean
Sourcepub unsafe fn is_none_or_nil(&self, index: i32) -> i32
pub unsafe fn is_none_or_nil(&self, index: i32) -> i32
lua_isnoneornil
Sourcepub unsafe fn is_integer64(&self, index: i32) -> i32
pub unsafe fn is_integer64(&self, index: i32) -> i32
lua_isinteger64
Sourcepub unsafe fn is_native_function(&self, index: i32) -> i32
pub unsafe fn is_native_function(&self, index: i32) -> i32
lua_iscfunction
Sourcepub unsafe fn is_lua_function(&self, index: i32) -> i32
pub unsafe fn is_lua_function(&self, index: i32) -> i32
lua_isLfunction
Sourcepub unsafe fn is_userdata(&self, index: i32) -> i32
pub unsafe fn is_userdata(&self, index: i32) -> i32
lua_isuserdata
Sourcepub unsafe fn to_integer(&self, index: i32) -> Option<i32>
pub unsafe fn to_integer(&self, index: i32) -> Option<i32>
lua_tointegerx
Sourcepub unsafe fn to_unsigned(&self, index: i32) -> Option<u32>
pub unsafe fn to_unsigned(&self, index: i32) -> Option<u32>
lua_tounsignedx
Sourcepub unsafe fn to_boolean(&self, index: i32) -> i32
pub unsafe fn to_boolean(&self, index: i32) -> i32
lua_toboolean
Sourcepub unsafe fn to_integer64(&self, index: i32) -> Option<i64>
pub unsafe fn to_integer64(&self, index: i32) -> Option<i64>
lua_tointeger64
Sourcepub unsafe fn namecall_atom(&self) -> Option<(&BStr, i32)>
pub unsafe fn namecall_atom(&self) -> Option<(&BStr, i32)>
lua_namecallatom
Sourcepub unsafe fn len(&self, index: i32) -> VmResult<f64>
pub unsafe fn len(&self, index: i32) -> VmResult<f64>
Numeric result of the Luau length operator (#).
Sourcepub unsafe fn to_pointer(&self, index: i32) -> *const ()
pub unsafe fn to_pointer(&self, index: i32) -> *const ()
lua_topointer
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn create_table(
&self,
array_size: usize,
record_size: usize,
) -> VmErrorResult
pub unsafe fn create_table( &self, array_size: usize, record_size: usize, ) -> VmErrorResult
lua_createtable
Sourcepub unsafe fn new_table(&self) -> VmErrorResult
pub unsafe fn new_table(&self) -> VmErrorResult
lua_newtable
Sourcepub unsafe fn get_field(
&self,
index: i32,
key: impl AsRef<[u8]>,
) -> VmResult<i32>
pub unsafe fn get_field( &self, index: i32, key: impl AsRef<[u8]>, ) -> VmResult<i32>
lua_getfield
Sourcepub unsafe fn raw_get_field(
&self,
index: i32,
key: impl AsRef<[u8]>,
) -> VmErrorResult<i32>
pub unsafe fn raw_get_field( &self, index: i32, key: impl AsRef<[u8]>, ) -> VmErrorResult<i32>
lua_rawgetfield
Sourcepub unsafe fn raw_getp_tagged(
&self,
index: i32,
key: *mut (),
tag: i32,
) -> VmErrorResult<i32>
pub unsafe fn raw_getp_tagged( &self, index: i32, key: *mut (), tag: i32, ) -> VmErrorResult<i32>
lua_rawgetptagged
Sourcepub unsafe fn set_readonly(&self, index: i32, enabled: i32)
pub unsafe fn set_readonly(&self, index: i32, enabled: i32)
lua_setreadonly
Sourcepub unsafe fn get_readonly(&self, index: i32) -> i32
pub unsafe fn get_readonly(&self, index: i32) -> i32
lua_getreadonly
Sourcepub unsafe fn set_safe_env(&self, index: i32, enabled: i32)
pub unsafe fn set_safe_env(&self, index: i32, enabled: i32)
lua_setsafeenv
Sourcepub unsafe fn get_metatable(&self, index: i32) -> VmErrorResult<i32>
pub unsafe fn get_metatable(&self, index: i32) -> VmErrorResult<i32>
lua_getmetatable
Sourcepub unsafe fn get_fenv(&self, index: i32) -> VmErrorResult
pub unsafe fn get_fenv(&self, index: i32) -> VmErrorResult
lua_getfenv
Sourcepub unsafe fn raw_set_field(
&self,
index: i32,
key: impl AsRef<[u8]>,
) -> VmErrorResult
pub unsafe fn raw_set_field( &self, index: i32, key: impl AsRef<[u8]>, ) -> VmErrorResult
lua_rawsetfield
Sourcepub unsafe fn set_global(&self, name: impl AsRef<[u8]>) -> VmErrorResult
pub unsafe fn set_global(&self, name: impl AsRef<[u8]>) -> VmErrorResult
lua_setglobal
Sourcepub unsafe fn raw_set(&self, index: i32) -> VmErrorResult
pub unsafe fn raw_set(&self, index: i32) -> VmErrorResult
lua_rawset
Sourcepub unsafe fn raw_seti(&self, index: i32, key: i32) -> VmErrorResult
pub unsafe fn raw_seti(&self, index: i32, key: i32) -> VmErrorResult
lua_rawseti
Sourcepub unsafe fn raw_setp_tagged(
&self,
index: i32,
key: *mut (),
tag: i32,
) -> VmErrorResult
pub unsafe fn raw_setp_tagged( &self, index: i32, key: *mut (), tag: i32, ) -> VmErrorResult
lua_rawsetptagged
Sourcepub unsafe fn set_metatable(&self, index: i32) -> VmErrorResult<i32>
pub unsafe fn set_metatable(&self, index: i32) -> VmErrorResult<i32>
lua_setmetatable
Sourcepub unsafe fn next(&self, index: i32) -> VmErrorResult<i32>
pub unsafe fn next(&self, index: i32) -> VmErrorResult<i32>
lua_next
Sourcepub unsafe fn clear_table(&self, index: i32) -> VmErrorResult
pub unsafe fn clear_table(&self, index: i32) -> VmErrorResult
lua_cleartable
Sourcepub unsafe fn clone_table(&self, index: i32) -> VmErrorResult
pub unsafe fn clone_table(&self, index: i32) -> VmErrorResult
lua_clonetable
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn get_ref(&self, reference: i32) -> VmErrorResult<i32>
pub unsafe fn get_ref(&self, reference: i32) -> VmErrorResult<i32>
lua_getref
Sourcepub unsafe fn ref_value(&self, index: i32) -> VmErrorResult<i32>
pub unsafe fn ref_value(&self, index: i32) -> VmErrorResult<i32>
lua_ref
Sourcepub unsafe fn unref_value(&self, reference: i32) -> i32
pub unsafe fn unref_value(&self, reference: i32) -> i32
lua_unref
Sourcepub unsafe fn weak_ref_value(&self, index: i32) -> VmErrorResult<i32>
pub unsafe fn weak_ref_value(&self, index: i32) -> VmErrorResult<i32>
lua_weakref
Sourcepub unsafe fn weak_unref_value(&self, reference: i32) -> i32
pub unsafe fn weak_unref_value(&self, reference: i32) -> i32
lua_weakunref
Sourcepub unsafe fn get_weak_ref(&self, reference: i32) -> VmErrorResult<i32>
pub unsafe fn get_weak_ref(&self, reference: i32) -> VmErrorResult<i32>
lua_getweakref
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn get_metafield(
&self,
index: i32,
event: &str,
) -> VmErrorResult<i32>
pub unsafe fn get_metafield( &self, index: i32, event: &str, ) -> VmErrorResult<i32>
luaL_getmetafield
Sourcepub unsafe fn new_metatable(&self, table_name: &str) -> VmErrorResult<i32>
pub unsafe fn new_metatable(&self, table_name: &str) -> VmErrorResult<i32>
luaL_newmetatable
Sourcepub unsafe fn find_table<'a, T>(
&self,
index: i32,
name: &'a T,
size_hint: usize,
) -> VmErrorResult<Option<&'a [u8]>>
pub unsafe fn find_table<'a, T>( &self, index: i32, name: &'a T, size_hint: usize, ) -> VmErrorResult<Option<&'a [u8]>>
luaL_findtable
Sourcepub unsafe fn register(
&self,
library_name: Option<&str>,
functions: &[NativeFunction],
) -> VmResult
pub unsafe fn register( &self, library_name: Option<&str>, functions: &[NativeFunction], ) -> VmResult
luaL_register
pub unsafe fn register_module(&self, module: &NativeModule) -> VmResult
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn sandbox(&self) -> VmErrorResult
pub unsafe fn sandbox(&self) -> VmErrorResult
luaL_sandbox
Safety
The caller must ensure that the current globals table can be made readonly and marked as a safe environment for future loads.
Sourcepub unsafe fn sandbox_thread(&self) -> VmErrorResult
pub unsafe fn sandbox_thread(&self) -> VmErrorResult
luaL_sandboxthread
Safety
The caller must ensure that the thread can have its globals table
replaced. If bytecode is loaded into the same sandboxed thread
environment more than once, the caller must clear safeenv before the
later load or install a fresh sandboxed environment first.
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn new_userdata_tagged(
&self,
size: usize,
tag: i32,
) -> VmErrorResult<*mut ()>
pub unsafe fn new_userdata_tagged( &self, size: usize, tag: i32, ) -> VmErrorResult<*mut ()>
lua_newuserdatatagged
Sourcepub unsafe fn new_userdata_tagged_with_metatable(
&self,
size: usize,
tag: i32,
) -> VmErrorResult<*mut ()>
pub unsafe fn new_userdata_tagged_with_metatable( &self, size: usize, tag: i32, ) -> VmErrorResult<*mut ()>
lua_newuserdatataggedwithmetatable
Sourcepub unsafe fn new_userdata_dtor(
&self,
size: usize,
destructor: LuaInlineDestructor,
) -> VmErrorResult<*mut ()>
pub unsafe fn new_userdata_dtor( &self, size: usize, destructor: LuaInlineDestructor, ) -> VmErrorResult<*mut ()>
lua_newuserdatadtor
Sourcepub unsafe fn new_userdata(&self, size: usize) -> VmErrorResult<*mut ()>
pub unsafe fn new_userdata(&self, size: usize) -> VmErrorResult<*mut ()>
lua_newuserdata
Sourcepub unsafe fn to_light_userdata(&self, index: i32) -> *mut ()
pub unsafe fn to_light_userdata(&self, index: i32) -> *mut ()
lua_tolightuserdata
Sourcepub unsafe fn to_light_userdata_tagged(&self, index: i32, tag: i32) -> *mut ()
pub unsafe fn to_light_userdata_tagged(&self, index: i32, tag: i32) -> *mut ()
lua_tolightuserdatatagged
Sourcepub unsafe fn to_userdata(&self, index: i32) -> *mut ()
pub unsafe fn to_userdata(&self, index: i32) -> *mut ()
lua_touserdata
Sourcepub unsafe fn userdata_tag(&self, index: i32) -> i32
pub unsafe fn userdata_tag(&self, index: i32) -> i32
lua_userdatatag
Sourcepub unsafe fn light_userdata_tag(&self, index: i32) -> i32
pub unsafe fn light_userdata_tag(&self, index: i32) -> i32
lua_lightuserdatatag
Sourcepub unsafe fn set_userdata_tag(&self, index: i32, tag: i32)
pub unsafe fn set_userdata_tag(&self, index: i32, tag: i32)
lua_setuserdatatag
Sourcepub unsafe fn set_userdata_dtor(&self, tag: i32, destructor: LuaDestructor)
pub unsafe fn set_userdata_dtor(&self, tag: i32, destructor: LuaDestructor)
lua_setuserdatadtor
Sourcepub unsafe fn get_userdata_dtor(&self, tag: i32) -> Option<LuaDestructor>
pub unsafe fn get_userdata_dtor(&self, tag: i32) -> Option<LuaDestructor>
lua_getuserdatadtor
Sourcepub unsafe fn set_userdata_mark(&self, tag: i32, mark: Option<LuaUserdataMark>)
pub unsafe fn set_userdata_mark(&self, tag: i32, mark: Option<LuaUserdataMark>)
lua_setuserdatamark
The callback runs during garbage collection and must not perform reentrant VM operations. Read-only host state access is permitted.
Sourcepub unsafe fn set_embedder_gc(&self, callback: Option<EmbedderGc>)
pub unsafe fn set_embedder_gc(&self, callback: Option<EmbedderGc>)
lua_setembeddergc
The callback runs during garbage collection and must not perform
reentrant VM operations. When mark is present, the callback may use
it to keep embedder-owned weak references alive for this cycle.
Sourcepub unsafe fn set_userdata_metatable(&self, tag: i32)
pub unsafe fn set_userdata_metatable(&self, tag: i32)
lua_setuserdatametatable
Sourcepub unsafe fn get_userdata_metatable(&self, tag: i32) -> VmErrorResult
pub unsafe fn get_userdata_metatable(&self, tag: i32) -> VmErrorResult
lua_getuserdatametatable
Sourcepub unsafe fn get_userdata_name(&self, tag: i32) -> LuaString
pub unsafe fn get_userdata_name(&self, tag: i32) -> LuaString
lua_getuserdataname
Sourcepub unsafe fn get_light_userdata_name(&self, tag: i32) -> Option<LuaString>
pub unsafe fn get_light_userdata_name(&self, tag: i32) -> Option<LuaString>
lua_getlightuserdataname
Sourcepub unsafe fn register_userdata_direct_access(
&self,
tag: i32,
get: LuaUserdataDirectAccess,
set: LuaUserdataDirectAccess,
namecall: Option<LuaUserdataDirectNamecall>,
) -> i32
pub unsafe fn register_userdata_direct_access( &self, tag: i32, get: LuaUserdataDirectAccess, set: LuaUserdataDirectAccess, namecall: Option<LuaUserdataDirectNamecall>, ) -> i32
lua_registeruserdatadirectaccess
Sourcepub unsafe fn register_userdata_direct_field_get(
&self,
tag: i32,
field: &[u8],
get: LuaUserdataDirectFieldGet,
) -> VmErrorResult
pub unsafe fn register_userdata_direct_field_get( &self, tag: i32, field: &[u8], get: LuaUserdataDirectFieldGet, ) -> VmErrorResult
lua_registeruserdatadirectfieldget
Sourcepub unsafe fn set_light_userdata_name(
&self,
tag: i32,
name: &str,
) -> VmErrorResult
pub unsafe fn set_light_userdata_name( &self, tag: i32, name: &str, ) -> VmErrorResult
lua_setlightuserdataname
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn global(&self) -> GlobalState
pub unsafe fn global(&self) -> GlobalState
Returns a non-owning handle to this thread’s global VM state.
Safety
This thread and its owning VM must still be live. The returned handle does not extend the global state’s lifetime or establish a borrow of the underlying record.
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn same_vm(&self, other: impl AsRef<Thread>) -> bool
pub unsafe fn same_vm(&self, other: impl AsRef<Thread>) -> bool
Returns whether both handles belong to the same VM.
Safety
Both threads and their owning VMs must still be live.
Sourcepub unsafe fn encode_pointer(&self, pointer: usize) -> usize
pub unsafe fn encode_pointer(&self, pointer: usize) -> usize
lua_encodepointer
Sourcepub unsafe fn set_pointer_encode_key(&self, a: u64, b: u64, c: u64, d: u64)
pub unsafe fn set_pointer_encode_key(&self, a: u64, b: u64, c: u64, d: u64)
lua_setpointerencodekey
Sourcepub unsafe fn reset(&self) -> VmErrorResult
pub unsafe fn reset(&self) -> VmErrorResult
lua_resetthread
Sourcepub unsafe fn is_yieldable(&self) -> i32
pub unsafe fn is_yieldable(&self) -> i32
lua_isyieldable
Sourcepub unsafe fn thread_data(&self) -> *mut ()
pub unsafe fn thread_data(&self) -> *mut ()
lua_getthreaddata
Sourcepub unsafe fn set_thread_data(&self, data: *mut ())
pub unsafe fn set_thread_data(&self, data: *mut ())
lua_setthreaddata
Sourcepub unsafe fn callbacks(&self) -> *mut LuaCallbacks
pub unsafe fn callbacks(&self) -> *mut LuaCallbacks
lua_callbacks
Returns the VM-owned callback record address. Mutating this record is only valid while the VM is quiescent, and the update must not be observable in a partially written state. The record is non-atomic and the pointer is not a cross-thread interruption mechanism.
Safety
The thread and its VM must remain live. The caller must not dereference a stale pointer or read or write the record concurrently with VM execution.
Sourceimpl Thread
impl Thread
Sourcepub unsafe fn push_thread(&self) -> VmErrorResult<i32>
pub unsafe fn push_thread(&self) -> VmErrorResult<i32>
lua_pushthread
Sourcepub unsafe fn new_thread(&self) -> VmErrorResult<Thread>
pub unsafe fn new_thread(&self) -> VmErrorResult<Thread>
lua_newthread