pub struct Proto { /* private fields */ }Expand description
Non-owning identity of a VM prototype record.
Safety model for unsafe methods
The proto and all referenced arrays and objects must remain live. Program counters and indices must be in bounds for their corresponding arrays, and code mutation must preserve a valid bytecode graph.
Implementations
Sourceimpl Proto
impl Proto
pub const unsafe fn from_raw(raw: NonNull<RawProto>) -> Self
pub unsafe fn source(&self) -> Option<TString>
pub unsafe fn debug_name(&self) -> Option<TString>
pub unsafe fn upvalue_name(&self, index: usize) -> Option<TString>
pub unsafe fn child_proto(&self, index: usize) -> Option<Self>
pub unsafe fn gc_list(&self) -> Option<GcObject>
pub unsafe fn set_gc_list(&self, gc_list: Option<GcObject>)
pub unsafe fn loc_var(&self, index: usize) -> Option<LocVar>
pub unsafe fn constants(&self) -> TValueCursor
pub unsafe fn constant(&self, index: usize) -> TValue
pub unsafe fn feedback_slot( &self, index: usize, ) -> Option<NonNull<FeedbackVectorSlot>>
pub unsafe fn code_at(&self, index: usize) -> u32
pub unsafe fn set_code_at(&self, index: usize, value: u32)