pub struct NativeArgument<'ctx, 'call> { /* private fields */ }Implementations
Sourceimpl<'ctx, 'call> NativeArgument<'ctx, 'call>
impl<'ctx, 'call> NativeArgument<'ctx, 'call>
pub const fn index(&self) -> i32
pub fn integer(&self) -> VmErrorResult<i32>
pub fn integer_or(&self, default: i32) -> VmErrorResult<i32>
pub fn number(&self) -> VmErrorResult<f64>
pub fn number_or(&self, default: f64) -> VmErrorResult<f64>
pub fn integer64(&self) -> VmErrorResult<i64>
pub fn integer64_or(&self, default: i64) -> VmErrorResult<i64>
pub fn unsigned(&self) -> VmErrorResult<u32>
pub fn vector(&self) -> VmErrorResult<[f32; 3]>
Sourcepub unsafe fn string(&self) -> VmErrorResult<&'ctx BStr>
pub unsafe fn string(&self) -> VmErrorResult<&'ctx BStr>
Returns a borrowed string argument.
Safety
The argument must remain rooted and no VM transition may pop, unroot, or collect it for the returned borrow’s lifetime.
pub fn light_userdata(&self) -> VmErrorResult<*mut ()>
Sourcepub unsafe fn userdata<T: 'static>(
&self,
) -> VmErrorResult<LuaUserdataRef<'ctx, T>>
pub unsafe fn userdata<T: 'static>( &self, ) -> VmErrorResult<LuaUserdataRef<'ctx, T>>
Borrows this argument as userdata of the registered type.
Safety
The argument must remain rooted and no VM transition may pop, unroot, or collect it while the returned guard is alive.
Sourcepub unsafe fn userdata_mut<T: 'static>(
&self,
) -> VmErrorResult<LuaUserdataRefMut<'ctx, T>>
pub unsafe fn userdata_mut<T: 'static>( &self, ) -> VmErrorResult<LuaUserdataRefMut<'ctx, T>>
Mutably borrows this argument as userdata of the registered type.
Safety
The argument must remain rooted and no VM transition may pop, unroot, or collect it while the returned guard is alive. No other access to the same typed value may overlap the mutable guard.
pub fn error<T>(&self, message: impl AsRef<[u8]>) -> VmErrorResult<T>
pub fn expected(&self, condition: bool, expected_type: &str) -> VmErrorResult
pub fn type_error<T>(&self, expected_type: &str) -> VmErrorResult<T>